/* system.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __SRC_SYSTEM_H__
#define __SRC_SYSTEM_H__

#include <switchboard.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <gmodule.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <packagekit-glib2/packagekit.h>
#include <fwupd.h>
#include <adwaita.h>
#include <gtk/gtk.h>
#include <granite-7.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define ABOUT_TYPE_PLUG (about_plug_get_type ())
#define ABOUT_PLUG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_PLUG, AboutPlug))
#define ABOUT_PLUG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_PLUG, AboutPlugClass))
#define ABOUT_IS_PLUG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_PLUG))
#define ABOUT_IS_PLUG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_PLUG))
#define ABOUT_PLUG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_PLUG, AboutPlugClass))

typedef struct _AboutPlug AboutPlug;
typedef struct _AboutPlugClass AboutPlugClass;
typedef struct _AboutPlugPrivate AboutPlugPrivate;

#define TYPE_SYSTEM_UPDATE (system_update_get_type ())
#define SYSTEM_UPDATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SYSTEM_UPDATE, SystemUpdate))
#define IS_SYSTEM_UPDATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SYSTEM_UPDATE))
#define SYSTEM_UPDATE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SYSTEM_UPDATE, SystemUpdateIface))

typedef struct _SystemUpdate SystemUpdate;
typedef struct _SystemUpdateIface SystemUpdateIface;

#define TYPE_SYSTEM_UPDATE_PROXY (system_update_proxy_get_type ())

#define SYSTEM_UPDATE_TYPE_CURRENT_STATE (system_update_current_state_get_type ())
typedef struct _SystemUpdateCurrentState SystemUpdateCurrentState;
typedef enum  {
	SYSTEM_UPDATE_STATE_UP_TO_DATE,
	SYSTEM_UPDATE_STATE_CHECKING,
	SYSTEM_UPDATE_STATE_AVAILABLE,
	SYSTEM_UPDATE_STATE_DOWNLOADING,
	SYSTEM_UPDATE_STATE_RESTART_REQUIRED,
	SYSTEM_UPDATE_STATE_ERROR
} SystemUpdateState;

#define SYSTEM_UPDATE_TYPE_STATE (system_update_state_get_type ())

#define SYSTEM_UPDATE_TYPE_UPDATE_DETAILS (system_update_update_details_get_type ())
typedef struct _SystemUpdateUpdateDetails SystemUpdateUpdateDetails;

#define TYPE_DRIVERS (drivers_get_type ())
#define DRIVERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DRIVERS, Drivers))
#define IS_DRIVERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DRIVERS))
#define DRIVERS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_DRIVERS, DriversIface))

typedef struct _Drivers Drivers;
typedef struct _DriversIface DriversIface;

#define TYPE_DRIVERS_PROXY (drivers_proxy_get_type ())

#define DRIVERS_TYPE_CURRENT_STATE (drivers_current_state_get_type ())
typedef struct _DriversCurrentState DriversCurrentState;
typedef enum  {
	DRIVERS_STATE_UP_TO_DATE,
	DRIVERS_STATE_CHECKING,
	DRIVERS_STATE_AVAILABLE,
	DRIVERS_STATE_DOWNLOADING,
	DRIVERS_STATE_RESTART_REQUIRED,
	DRIVERS_STATE_ERROR
} DriversState;

#define DRIVERS_TYPE_STATE (drivers_state_get_type ())

#define ABOUT_TYPE_FIRMWARE_CLIENT (about_firmware_client_get_type ())
#define ABOUT_FIRMWARE_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_FIRMWARE_CLIENT, AboutFirmwareClient))
#define ABOUT_FIRMWARE_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_FIRMWARE_CLIENT, AboutFirmwareClientClass))
#define ABOUT_IS_FIRMWARE_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_FIRMWARE_CLIENT))
#define ABOUT_IS_FIRMWARE_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_FIRMWARE_CLIENT))
#define ABOUT_FIRMWARE_CLIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_FIRMWARE_CLIENT, AboutFirmwareClientClass))

typedef struct _AboutFirmwareClient AboutFirmwareClient;
typedef struct _AboutFirmwareClientClass AboutFirmwareClientClass;
typedef struct _AboutFirmwareClientPrivate AboutFirmwareClientPrivate;

#define ABOUT_TYPE_LOGIN_INTERFACE (about_login_interface_get_type ())
#define ABOUT_LOGIN_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_LOGIN_INTERFACE, AboutLoginInterface))
#define ABOUT_IS_LOGIN_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_LOGIN_INTERFACE))
#define ABOUT_LOGIN_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), ABOUT_TYPE_LOGIN_INTERFACE, AboutLoginInterfaceIface))

typedef struct _AboutLoginInterface AboutLoginInterface;
typedef struct _AboutLoginInterfaceIface AboutLoginInterfaceIface;

#define ABOUT_TYPE_LOGIN_INTERFACE_PROXY (about_login_interface_proxy_get_type ())

#define ABOUT_TYPE_LOGIN_MANAGER (about_login_manager_get_type ())
#define ABOUT_LOGIN_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_LOGIN_MANAGER, AboutLoginManager))
#define ABOUT_LOGIN_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_LOGIN_MANAGER, AboutLoginManagerClass))
#define ABOUT_IS_LOGIN_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_LOGIN_MANAGER))
#define ABOUT_IS_LOGIN_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_LOGIN_MANAGER))
#define ABOUT_LOGIN_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_LOGIN_MANAGER, AboutLoginManagerClass))

typedef struct _AboutLoginManager AboutLoginManager;
typedef struct _AboutLoginManagerClass AboutLoginManagerClass;
typedef struct _AboutLoginManagerPrivate AboutLoginManagerPrivate;

#define ABOUT_TYPE_ARM_PART_DECODER (about_arm_part_decoder_get_type ())
#define ABOUT_ARM_PART_DECODER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_ARM_PART_DECODER, AboutARMPartDecoder))
#define ABOUT_ARM_PART_DECODER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_ARM_PART_DECODER, AboutARMPartDecoderClass))
#define ABOUT_IS_ARM_PART_DECODER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_ARM_PART_DECODER))
#define ABOUT_IS_ARM_PART_DECODER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_ARM_PART_DECODER))
#define ABOUT_ARM_PART_DECODER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_ARM_PART_DECODER, AboutARMPartDecoderClass))

typedef struct _AboutARMPartDecoder AboutARMPartDecoder;
typedef struct _AboutARMPartDecoderClass AboutARMPartDecoderClass;
typedef struct _AboutARMPartDecoderPrivate AboutARMPartDecoderPrivate;

#define ABOUT_TYPE_DRIVERS_VIEW (about_drivers_view_get_type ())
#define ABOUT_DRIVERS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_DRIVERS_VIEW, AboutDriversView))
#define ABOUT_DRIVERS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_DRIVERS_VIEW, AboutDriversViewClass))
#define ABOUT_IS_DRIVERS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_DRIVERS_VIEW))
#define ABOUT_IS_DRIVERS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_DRIVERS_VIEW))
#define ABOUT_DRIVERS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_DRIVERS_VIEW, AboutDriversViewClass))

typedef struct _AboutDriversView AboutDriversView;
typedef struct _AboutDriversViewClass AboutDriversViewClass;
typedef struct _AboutDriversViewPrivate AboutDriversViewPrivate;

#define ABOUT_TYPE_FIRMWARE_RELEASE_VIEW (about_firmware_release_view_get_type ())
#define ABOUT_FIRMWARE_RELEASE_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_FIRMWARE_RELEASE_VIEW, AboutFirmwareReleaseView))
#define ABOUT_FIRMWARE_RELEASE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_FIRMWARE_RELEASE_VIEW, AboutFirmwareReleaseViewClass))
#define ABOUT_IS_FIRMWARE_RELEASE_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_FIRMWARE_RELEASE_VIEW))
#define ABOUT_IS_FIRMWARE_RELEASE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_FIRMWARE_RELEASE_VIEW))
#define ABOUT_FIRMWARE_RELEASE_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_FIRMWARE_RELEASE_VIEW, AboutFirmwareReleaseViewClass))

typedef struct _AboutFirmwareReleaseView AboutFirmwareReleaseView;
typedef struct _AboutFirmwareReleaseViewClass AboutFirmwareReleaseViewClass;
typedef struct _AboutFirmwareReleaseViewPrivate AboutFirmwareReleaseViewPrivate;

#define ABOUT_TYPE_FIRMWARE_VIEW (about_firmware_view_get_type ())
#define ABOUT_FIRMWARE_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_FIRMWARE_VIEW, AboutFirmwareView))
#define ABOUT_FIRMWARE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_FIRMWARE_VIEW, AboutFirmwareViewClass))
#define ABOUT_IS_FIRMWARE_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_FIRMWARE_VIEW))
#define ABOUT_IS_FIRMWARE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_FIRMWARE_VIEW))
#define ABOUT_FIRMWARE_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_FIRMWARE_VIEW, AboutFirmwareViewClass))

typedef struct _AboutFirmwareView AboutFirmwareView;
typedef struct _AboutFirmwareViewClass AboutFirmwareViewClass;
typedef struct _AboutFirmwareViewPrivate AboutFirmwareViewPrivate;

#define ABOUT_TYPE_HARDWARE_VIEW (about_hardware_view_get_type ())
#define ABOUT_HARDWARE_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_HARDWARE_VIEW, AboutHardwareView))
#define ABOUT_HARDWARE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_HARDWARE_VIEW, AboutHardwareViewClass))
#define ABOUT_IS_HARDWARE_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_HARDWARE_VIEW))
#define ABOUT_IS_HARDWARE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_HARDWARE_VIEW))
#define ABOUT_HARDWARE_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_HARDWARE_VIEW, AboutHardwareViewClass))

typedef struct _AboutHardwareView AboutHardwareView;
typedef struct _AboutHardwareViewClass AboutHardwareViewClass;
typedef struct _AboutHardwareViewPrivate AboutHardwareViewPrivate;

#define TYPE_SYSTEM_INTERFACE (system_interface_get_type ())
#define SYSTEM_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SYSTEM_INTERFACE, SystemInterface))
#define IS_SYSTEM_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SYSTEM_INTERFACE))
#define SYSTEM_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SYSTEM_INTERFACE, SystemInterfaceIface))

typedef struct _SystemInterface SystemInterface;
typedef struct _SystemInterfaceIface SystemInterfaceIface;

#define TYPE_SYSTEM_INTERFACE_PROXY (system_interface_proxy_get_type ())

#define TYPE_SESSION_MANAGER (session_manager_get_type ())
#define SESSION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SESSION_MANAGER, SessionManager))
#define IS_SESSION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SESSION_MANAGER))
#define SESSION_MANAGER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SESSION_MANAGER, SessionManagerIface))

typedef struct _SessionManager SessionManager;
typedef struct _SessionManagerIface SessionManagerIface;

#define TYPE_SESSION_MANAGER_PROXY (session_manager_proxy_get_type ())

#define TYPE_SWITCHEROO_CONTROL (switcheroo_control_get_type ())
#define SWITCHEROO_CONTROL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SWITCHEROO_CONTROL, SwitcherooControl))
#define IS_SWITCHEROO_CONTROL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SWITCHEROO_CONTROL))
#define SWITCHEROO_CONTROL_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SWITCHEROO_CONTROL, SwitcherooControlIface))

typedef struct _SwitcherooControl SwitcherooControl;
typedef struct _SwitcherooControlIface SwitcherooControlIface;

#define TYPE_SWITCHEROO_CONTROL_PROXY (switcheroo_control_proxy_get_type ())

#define ABOUT_TYPE_OPERATING_SYSTEM_VIEW (about_operating_system_view_get_type ())
#define ABOUT_OPERATING_SYSTEM_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_OPERATING_SYSTEM_VIEW, AboutOperatingSystemView))
#define ABOUT_OPERATING_SYSTEM_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_OPERATING_SYSTEM_VIEW, AboutOperatingSystemViewClass))
#define ABOUT_IS_OPERATING_SYSTEM_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_OPERATING_SYSTEM_VIEW))
#define ABOUT_IS_OPERATING_SYSTEM_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_OPERATING_SYSTEM_VIEW))
#define ABOUT_OPERATING_SYSTEM_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_OPERATING_SYSTEM_VIEW, AboutOperatingSystemViewClass))

typedef struct _AboutOperatingSystemView AboutOperatingSystemView;
typedef struct _AboutOperatingSystemViewClass AboutOperatingSystemViewClass;
typedef struct _AboutOperatingSystemViewPrivate AboutOperatingSystemViewPrivate;

#define ABOUT_WIDGETS_TYPE_FIRMWARE_UPDATE_ROW (about_widgets_firmware_update_row_get_type ())
#define ABOUT_WIDGETS_FIRMWARE_UPDATE_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_WIDGETS_TYPE_FIRMWARE_UPDATE_ROW, AboutWidgetsFirmwareUpdateRow))
#define ABOUT_WIDGETS_FIRMWARE_UPDATE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_WIDGETS_TYPE_FIRMWARE_UPDATE_ROW, AboutWidgetsFirmwareUpdateRowClass))
#define ABOUT_WIDGETS_IS_FIRMWARE_UPDATE_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_WIDGETS_TYPE_FIRMWARE_UPDATE_ROW))
#define ABOUT_WIDGETS_IS_FIRMWARE_UPDATE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_WIDGETS_TYPE_FIRMWARE_UPDATE_ROW))
#define ABOUT_WIDGETS_FIRMWARE_UPDATE_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_WIDGETS_TYPE_FIRMWARE_UPDATE_ROW, AboutWidgetsFirmwareUpdateRowClass))

typedef struct _AboutWidgetsFirmwareUpdateRow AboutWidgetsFirmwareUpdateRow;
typedef struct _AboutWidgetsFirmwareUpdateRowClass AboutWidgetsFirmwareUpdateRowClass;
typedef struct _AboutWidgetsFirmwareUpdateRowPrivate AboutWidgetsFirmwareUpdateRowPrivate;

#define ABOUT_TYPE_DRIVER_ROW (about_driver_row_get_type ())
#define ABOUT_DRIVER_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_DRIVER_ROW, AboutDriverRow))
#define ABOUT_DRIVER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_DRIVER_ROW, AboutDriverRowClass))
#define ABOUT_IS_DRIVER_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_DRIVER_ROW))
#define ABOUT_IS_DRIVER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_DRIVER_ROW))
#define ABOUT_DRIVER_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_DRIVER_ROW, AboutDriverRowClass))

typedef struct _AboutDriverRow AboutDriverRow;
typedef struct _AboutDriverRowClass AboutDriverRowClass;
typedef struct _AboutDriverRowPrivate AboutDriverRowPrivate;

#define ABOUT_TYPE_UPDATE_DETAILS_DIALOG (about_update_details_dialog_get_type ())
#define ABOUT_UPDATE_DETAILS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_UPDATE_DETAILS_DIALOG, AboutUpdateDetailsDialog))
#define ABOUT_UPDATE_DETAILS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_UPDATE_DETAILS_DIALOG, AboutUpdateDetailsDialogClass))
#define ABOUT_IS_UPDATE_DETAILS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_UPDATE_DETAILS_DIALOG))
#define ABOUT_IS_UPDATE_DETAILS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_UPDATE_DETAILS_DIALOG))
#define ABOUT_UPDATE_DETAILS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_UPDATE_DETAILS_DIALOG, AboutUpdateDetailsDialogClass))

typedef struct _AboutUpdateDetailsDialog AboutUpdateDetailsDialog;
typedef struct _AboutUpdateDetailsDialogClass AboutUpdateDetailsDialogClass;
typedef struct _AboutUpdateDetailsDialogPrivate AboutUpdateDetailsDialogPrivate;

struct _AboutPlug {
	SwitchboardPlug parent_instance;
	AboutPlugPrivate * priv;
};

struct _AboutPlugClass {
	SwitchboardPlugClass parent_class;
};

struct _SystemUpdateCurrentState {
	SystemUpdateState state;
	gchar* message;
	guint percentage;
	guint64 download_size_remaining;
};

struct _SystemUpdateUpdateDetails {
	gchar** packages;
	gint packages_length1;
	guint64 size;
	PkInfoEnum* info;
	gint info_length1;
};

struct _SystemUpdateIface {
	GTypeInterface parent_iface;
	void (*get_current_state) (SystemUpdate* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*get_current_state_finish) (SystemUpdate* self, GAsyncResult* _res_, SystemUpdateCurrentState* result, GError** error);
	void (*get_update_details) (SystemUpdate* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*get_update_details_finish) (SystemUpdate* self, GAsyncResult* _res_, SystemUpdateUpdateDetails* result, GError** error);
	void (*cancel) (SystemUpdate* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*cancel_finish) (SystemUpdate* self, GAsyncResult* _res_, GError** error);
	void (*check_for_updates) (SystemUpdate* self, gboolean force, gboolean notify, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*check_for_updates_finish) (SystemUpdate* self, GAsyncResult* _res_, GError** error);
	void (*update) (SystemUpdate* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*update_finish) (SystemUpdate* self, GAsyncResult* _res_, GError** error);
	void (*get_last_refresh_time) (SystemUpdate* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gint64 (*get_last_refresh_time_finish) (SystemUpdate* self, GAsyncResult* _res_, GError** error);
};

struct _DriversCurrentState {
	DriversState state;
	gchar* message;
};

struct _DriversIface {
	GTypeInterface parent_iface;
	void (*get_current_state) (Drivers* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*get_current_state_finish) (Drivers* self, GAsyncResult* _res_, DriversCurrentState* result, GError** error);
	void (*get_available_drivers) (Drivers* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GHashTable* (*get_available_drivers_finish) (Drivers* self, GAsyncResult* _res_, GError** error);
	void (*cancel) (Drivers* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*cancel_finish) (Drivers* self, GAsyncResult* _res_, GError** error);
	void (*check_for_drivers) (Drivers* self, gboolean notify, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*check_for_drivers_finish) (Drivers* self, GAsyncResult* _res_, GError** error);
	void (*install) (Drivers* self, const gchar* name, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*install_finish) (Drivers* self, GAsyncResult* _res_, GError** error);
};

struct _AboutFirmwareClient {
	GTypeInstance parent_instance;
	volatile int ref_count;
	AboutFirmwareClientPrivate * priv;
};

struct _AboutFirmwareClientClass {
	GTypeClass parent_class;
	void (*finalize) (AboutFirmwareClient *self);
};

struct _AboutLoginInterfaceIface {
	GTypeInterface parent_iface;
	void (*reboot) (AboutLoginInterface* self, gboolean interactive, GError** error);
	void (*power_off) (AboutLoginInterface* self, gboolean interactive, GError** error);
	void (*set_reboot_to_firmware_setup) (AboutLoginInterface* self, gboolean interactive, GError** error);
	gchar* (*can_reboot_to_firmware_setup) (AboutLoginInterface* self, GError** error);
};

struct _AboutLoginManager {
	GObject parent_instance;
	AboutLoginManagerPrivate * priv;
};

struct _AboutLoginManagerClass {
	GObjectClass parent_class;
};

struct _AboutARMPartDecoder {
	GTypeInstance parent_instance;
	volatile int ref_count;
	AboutARMPartDecoderPrivate * priv;
};

struct _AboutARMPartDecoderClass {
	GTypeClass parent_class;
	void (*finalize) (AboutARMPartDecoder *self);
};

struct _AboutDriversView {
	SwitchboardSettingsPage parent_instance;
	AboutDriversViewPrivate * priv;
};

struct _AboutDriversViewClass {
	SwitchboardSettingsPageClass parent_class;
};

struct _AboutFirmwareReleaseView {
	AdwNavigationPage parent_instance;
	AboutFirmwareReleaseViewPrivate * priv;
};

struct _AboutFirmwareReleaseViewClass {
	AdwNavigationPageClass parent_class;
};

struct _AboutFirmwareView {
	SwitchboardSettingsPage parent_instance;
	AboutFirmwareViewPrivate * priv;
};

struct _AboutFirmwareViewClass {
	SwitchboardSettingsPageClass parent_class;
};

struct _AboutHardwareView {
	GtkBox parent_instance;
	AboutHardwareViewPrivate * priv;
};

struct _AboutHardwareViewClass {
	GtkBoxClass parent_class;
};

struct _SystemInterfaceIface {
	GTypeInterface parent_iface;
	void (*set_pretty_hostname) (SystemInterface* self, const gchar* hostname, gboolean interactive, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*set_pretty_hostname_finish) (SystemInterface* self, GAsyncResult* _res_, GError** error);
	void (*set_static_hostname) (SystemInterface* self, const gchar* hostname, gboolean interactive, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*set_static_hostname_finish) (SystemInterface* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_icon_name) (SystemInterface* self);
	gchar* (*get_pretty_hostname) (SystemInterface* self);
	gchar* (*get_static_hostname) (SystemInterface* self);
};

struct _SessionManagerIface {
	GTypeInterface parent_iface;
	gchar* (*get_renderer) (SessionManager* self);
};

struct _SwitcherooControlIface {
	GTypeInterface parent_iface;
	gboolean (*get_has_dual_gpu) (SwitcherooControl* self);
	GHashTable** (*get_gpus) (SwitcherooControl* self, gint* result_length1);
};

struct _AboutOperatingSystemView {
	GtkBox parent_instance;
	AboutOperatingSystemViewPrivate * priv;
};

struct _AboutOperatingSystemViewClass {
	GtkBoxClass parent_class;
};

struct _AboutWidgetsFirmwareUpdateRow {
	GtkListBoxRow parent_instance;
	AboutWidgetsFirmwareUpdateRowPrivate * priv;
};

struct _AboutWidgetsFirmwareUpdateRowClass {
	GtkListBoxRowClass parent_class;
};

struct _AboutDriverRow {
	GtkListBoxRow parent_instance;
	AboutDriverRowPrivate * priv;
};

struct _AboutDriverRowClass {
	GtkListBoxRowClass parent_class;
};

struct _AboutUpdateDetailsDialog {
	GraniteDialog parent_instance;
	AboutUpdateDetailsDialogPrivate * priv;
};

struct _AboutUpdateDetailsDialogClass {
	GraniteDialogClass parent_class;
};

VALA_EXTERN GType about_plug_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutPlug, g_object_unref)
VALA_EXTERN AboutPlug* about_plug_new (void);
VALA_EXTERN AboutPlug* about_plug_construct (GType object_type);
VALA_EXTERN SwitchboardPlug* get_plug (GModule* module);
VALA_EXTERN GType system_update_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint system_update_register_object (void* object,
                                     GDBusConnection* connection,
                                     const gchar* path,
                                     GError** error);
VALA_EXTERN GType system_update_current_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType system_update_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN SystemUpdateCurrentState* system_update_current_state_dup (const SystemUpdateCurrentState* self);
VALA_EXTERN void system_update_current_state_free (SystemUpdateCurrentState* self);
VALA_EXTERN void system_update_current_state_copy (const SystemUpdateCurrentState* self,
                                       SystemUpdateCurrentState* dest);
VALA_EXTERN void system_update_current_state_destroy (SystemUpdateCurrentState* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (SystemUpdateCurrentState, system_update_current_state_destroy)
VALA_EXTERN GType system_update_update_details_get_type (void) G_GNUC_CONST ;
VALA_EXTERN SystemUpdateUpdateDetails* system_update_update_details_dup (const SystemUpdateUpdateDetails* self);
VALA_EXTERN void system_update_update_details_free (SystemUpdateUpdateDetails* self);
VALA_EXTERN void system_update_update_details_copy (const SystemUpdateUpdateDetails* self,
                                        SystemUpdateUpdateDetails* dest);
VALA_EXTERN void system_update_update_details_destroy (SystemUpdateUpdateDetails* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (SystemUpdateUpdateDetails, system_update_update_details_destroy)
VALA_EXTERN GType system_update_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SystemUpdate, g_object_unref)
VALA_EXTERN void system_update_get_current_state (SystemUpdate* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void system_update_get_current_state_finish (SystemUpdate* self,
                                             GAsyncResult* _res_,
                                             SystemUpdateCurrentState* result,
                                             GError** error);
VALA_EXTERN void system_update_get_update_details (SystemUpdate* self,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN void system_update_get_update_details_finish (SystemUpdate* self,
                                              GAsyncResult* _res_,
                                              SystemUpdateUpdateDetails* result,
                                              GError** error);
VALA_EXTERN void system_update_cancel (SystemUpdate* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN void system_update_cancel_finish (SystemUpdate* self,
                                  GAsyncResult* _res_,
                                  GError** error);
VALA_EXTERN void system_update_check_for_updates (SystemUpdate* self,
                                      gboolean force,
                                      gboolean notify,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void system_update_check_for_updates_finish (SystemUpdate* self,
                                             GAsyncResult* _res_,
                                             GError** error);
VALA_EXTERN void system_update_update (SystemUpdate* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN void system_update_update_finish (SystemUpdate* self,
                                  GAsyncResult* _res_,
                                  GError** error);
VALA_EXTERN void system_update_get_last_refresh_time (SystemUpdate* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN gint64 system_update_get_last_refresh_time_finish (SystemUpdate* self,
                                                   GAsyncResult* _res_,
                                                   GError** error);
VALA_EXTERN GType drivers_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint drivers_register_object (void* object,
                               GDBusConnection* connection,
                               const gchar* path,
                               GError** error);
VALA_EXTERN GType drivers_current_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType drivers_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DriversCurrentState* drivers_current_state_dup (const DriversCurrentState* self);
VALA_EXTERN void drivers_current_state_free (DriversCurrentState* self);
VALA_EXTERN void drivers_current_state_copy (const DriversCurrentState* self,
                                 DriversCurrentState* dest);
VALA_EXTERN void drivers_current_state_destroy (DriversCurrentState* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (DriversCurrentState, drivers_current_state_destroy)
VALA_EXTERN GType drivers_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Drivers, g_object_unref)
VALA_EXTERN void drivers_get_current_state (Drivers* self,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN void drivers_get_current_state_finish (Drivers* self,
                                       GAsyncResult* _res_,
                                       DriversCurrentState* result,
                                       GError** error);
VALA_EXTERN void drivers_get_available_drivers (Drivers* self,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN GHashTable* drivers_get_available_drivers_finish (Drivers* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN void drivers_cancel (Drivers* self,
                     GAsyncReadyCallback _callback_,
                     gpointer _user_data_);
VALA_EXTERN void drivers_cancel_finish (Drivers* self,
                            GAsyncResult* _res_,
                            GError** error);
VALA_EXTERN void drivers_check_for_drivers (Drivers* self,
                                gboolean notify,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN void drivers_check_for_drivers_finish (Drivers* self,
                                       GAsyncResult* _res_,
                                       GError** error);
VALA_EXTERN void drivers_install (Drivers* self,
                      const gchar* name,
                      GAsyncReadyCallback _callback_,
                      gpointer _user_data_);
VALA_EXTERN void drivers_install_finish (Drivers* self,
                             GAsyncResult* _res_,
                             GError** error);
VALA_EXTERN gpointer about_firmware_client_ref (gpointer instance);
VALA_EXTERN void about_firmware_client_unref (gpointer instance);
VALA_EXTERN GParamSpec* about_param_spec_firmware_client (const gchar* name,
                                              const gchar* nick,
                                              const gchar* blurb,
                                              GType object_type,
                                              GParamFlags flags);
VALA_EXTERN void about_value_set_firmware_client (GValue* value,
                                      gpointer v_object);
VALA_EXTERN void about_value_take_firmware_client (GValue* value,
                                       gpointer v_object);
VALA_EXTERN gpointer about_value_get_firmware_client (const GValue* value);
VALA_EXTERN GType about_firmware_client_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutFirmwareClient, about_firmware_client_unref)
VALA_EXTERN void about_firmware_client_get_devices (FwupdClient* client,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN GPtrArray* about_firmware_client_get_devices_finish (GAsyncResult* _res_,
                                                     GError** error);
VALA_EXTERN void about_firmware_client_get_upgrades (FwupdClient* client,
                                         const gchar* device_id,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN GPtrArray* about_firmware_client_get_upgrades_finish (GAsyncResult* _res_,
                                                      GError** error);
VALA_EXTERN void about_firmware_client_install (FwupdClient* client,
                                    const gchar* device_id,
                                    const gchar* path,
                                    FwupdInstallFlags install_flags,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN gboolean about_firmware_client_install_finish (GAsyncResult* _res_,
                                               GError** error);
VALA_EXTERN AboutFirmwareClient* about_firmware_client_new (void);
VALA_EXTERN AboutFirmwareClient* about_firmware_client_construct (GType object_type);
VALA_EXTERN GType about_login_interface_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint about_login_interface_register_object (void* object,
                                             GDBusConnection* connection,
                                             const gchar* path,
                                             GError** error);
VALA_EXTERN GType about_login_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutLoginInterface, g_object_unref)
VALA_EXTERN void about_login_interface_reboot (AboutLoginInterface* self,
                                   gboolean interactive,
                                   GError** error);
VALA_EXTERN void about_login_interface_power_off (AboutLoginInterface* self,
                                      gboolean interactive,
                                      GError** error);
VALA_EXTERN void about_login_interface_set_reboot_to_firmware_setup (AboutLoginInterface* self,
                                                         gboolean interactive,
                                                         GError** error);
VALA_EXTERN gchar* about_login_interface_can_reboot_to_firmware_setup (AboutLoginInterface* self,
                                                           GError** error);
VALA_EXTERN GType about_login_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutLoginManager, g_object_unref)
VALA_EXTERN AboutLoginManager* about_login_manager_get_instance (void);
VALA_EXTERN gboolean about_login_manager_shutdown (AboutLoginManager* self);
VALA_EXTERN gboolean about_login_manager_reboot (AboutLoginManager* self);
VALA_EXTERN GError* about_login_manager_set_reboot_to_firmware_setup (AboutLoginManager* self);
VALA_EXTERN gboolean about_login_manager_can_reboot_to_firmware_setup (AboutLoginManager* self);
VALA_EXTERN gpointer about_arm_part_decoder_ref (gpointer instance);
VALA_EXTERN void about_arm_part_decoder_unref (gpointer instance);
VALA_EXTERN GParamSpec* about_param_spec_arm_part_decoder (const gchar* name,
                                               const gchar* nick,
                                               const gchar* blurb,
                                               GType object_type,
                                               GParamFlags flags);
VALA_EXTERN void about_value_set_arm_part_decoder (GValue* value,
                                       gpointer v_object);
VALA_EXTERN void about_value_take_arm_part_decoder (GValue* value,
                                        gpointer v_object);
VALA_EXTERN gpointer about_value_get_arm_part_decoder (const GValue* value);
VALA_EXTERN GType about_arm_part_decoder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutARMPartDecoder, about_arm_part_decoder_unref)
VALA_EXTERN gchar* about_arm_part_decoder_decode_arm_model (const gchar* cpu_implementer,
                                                const gchar* cpu_part);
VALA_EXTERN AboutARMPartDecoder* about_arm_part_decoder_new (void);
VALA_EXTERN AboutARMPartDecoder* about_arm_part_decoder_construct (GType object_type);
VALA_EXTERN GType about_drivers_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutDriversView, g_object_unref)
VALA_EXTERN AboutDriversView* about_drivers_view_new (void);
VALA_EXTERN AboutDriversView* about_drivers_view_construct (GType object_type);
VALA_EXTERN GType about_firmware_release_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutFirmwareReleaseView, g_object_unref)
VALA_EXTERN void about_firmware_release_view_update_view (AboutFirmwareReleaseView* self,
                                              FwupdDevice* device,
                                              FwupdRelease* release);
VALA_EXTERN AboutFirmwareReleaseView* about_firmware_release_view_new (void);
VALA_EXTERN AboutFirmwareReleaseView* about_firmware_release_view_construct (GType object_type);
VALA_EXTERN GType about_firmware_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutFirmwareView, g_object_unref)
VALA_EXTERN AboutFirmwareView* about_firmware_view_new (void);
VALA_EXTERN AboutFirmwareView* about_firmware_view_construct (GType object_type);
VALA_EXTERN GType about_hardware_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutHardwareView, g_object_unref)
VALA_EXTERN AboutHardwareView* about_hardware_view_new (void);
VALA_EXTERN AboutHardwareView* about_hardware_view_construct (GType object_type);
VALA_EXTERN GType system_interface_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint system_interface_register_object (void* object,
                                        GDBusConnection* connection,
                                        const gchar* path,
                                        GError** error);
VALA_EXTERN GType system_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SystemInterface, g_object_unref)
VALA_EXTERN void system_interface_set_pretty_hostname (SystemInterface* self,
                                           const gchar* hostname,
                                           gboolean interactive,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN void system_interface_set_pretty_hostname_finish (SystemInterface* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN void system_interface_set_static_hostname (SystemInterface* self,
                                           const gchar* hostname,
                                           gboolean interactive,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN void system_interface_set_static_hostname_finish (SystemInterface* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN gchar* system_interface_get_icon_name (SystemInterface* self);
VALA_EXTERN gchar* system_interface_get_pretty_hostname (SystemInterface* self);
VALA_EXTERN gchar* system_interface_get_static_hostname (SystemInterface* self);
VALA_EXTERN GType session_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SessionManager, g_object_unref)
VALA_EXTERN GType session_manager_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint session_manager_register_object (void* object,
                                       GDBusConnection* connection,
                                       const gchar* path,
                                       GError** error);
VALA_EXTERN gchar* session_manager_get_renderer (SessionManager* self);
VALA_EXTERN GType switcheroo_control_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SwitcherooControl, g_object_unref)
VALA_EXTERN GType switcheroo_control_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint switcheroo_control_register_object (void* object,
                                          GDBusConnection* connection,
                                          const gchar* path,
                                          GError** error);
VALA_EXTERN gboolean switcheroo_control_get_has_dual_gpu (SwitcherooControl* self);
VALA_EXTERN GHashTable** switcheroo_control_get_gpus (SwitcherooControl* self,
                                          gint* result_length1);
VALA_EXTERN GType about_operating_system_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutOperatingSystemView, g_object_unref)
VALA_EXTERN void about_operating_system_view_load_logo (AboutOperatingSystemView* self,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN void about_operating_system_view_load_logo_finish (AboutOperatingSystemView* self,
                                                   GAsyncResult* _res_);
VALA_EXTERN void about_operating_system_view_load_sponsors_goal (AboutOperatingSystemView* self,
                                                     GCancellable* cancellable);
VALA_EXTERN AboutOperatingSystemView* about_operating_system_view_new (void);
VALA_EXTERN AboutOperatingSystemView* about_operating_system_view_construct (GType object_type);
VALA_EXTERN GType about_widgets_firmware_update_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutWidgetsFirmwareUpdateRow, g_object_unref)
VALA_EXTERN AboutWidgetsFirmwareUpdateRow* about_widgets_firmware_update_row_new (FwupdDevice* device,
                                                                      FwupdRelease* release);
VALA_EXTERN AboutWidgetsFirmwareUpdateRow* about_widgets_firmware_update_row_construct (GType object_type,
                                                                            FwupdDevice* device,
                                                                            FwupdRelease* release);
VALA_EXTERN FwupdDevice* about_widgets_firmware_update_row_get_device (AboutWidgetsFirmwareUpdateRow* self);
VALA_EXTERN FwupdRelease* about_widgets_firmware_update_row_get_release (AboutWidgetsFirmwareUpdateRow* self);
VALA_EXTERN gboolean about_widgets_firmware_update_row_get_is_updatable (AboutWidgetsFirmwareUpdateRow* self);
VALA_EXTERN GType about_driver_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutDriverRow, g_object_unref)
VALA_EXTERN AboutDriverRow* about_driver_row_new (const gchar* device,
                                      const gchar* driver_name,
                                      gboolean installed);
VALA_EXTERN AboutDriverRow* about_driver_row_construct (GType object_type,
                                            const gchar* device,
                                            const gchar* driver_name,
                                            gboolean installed);
VALA_EXTERN const gchar* about_driver_row_get_device (AboutDriverRow* self);
VALA_EXTERN const gchar* about_driver_row_get_driver_name (AboutDriverRow* self);
VALA_EXTERN gboolean about_driver_row_get_installed (AboutDriverRow* self);
VALA_EXTERN GtkCheckButton* about_driver_row_get_install_button (AboutDriverRow* self);
VALA_EXTERN GType about_update_details_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AboutUpdateDetailsDialog, g_object_unref)
VALA_EXTERN AboutUpdateDetailsDialog* about_update_details_dialog_new (GtkStringList* packages);
VALA_EXTERN AboutUpdateDetailsDialog* about_update_details_dialog_construct (GType object_type,
                                                                 GtkStringList* packages);
VALA_EXTERN GtkStringList* about_update_details_dialog_get_packages (AboutUpdateDetailsDialog* self);

G_END_DECLS

#endif
